@@ -700,6 +700,46 @@ async def test_job_with_live_action(live_config_loader: ConfigLoader) -> None:
     assert not job.browse
 
 
+async def test_job_with_live_module(live_config_loader: ConfigLoader) -> None:
+    flow = await RunningLiveFlow.create(live_config_loader, "live-module-call")
+    job = await flow.get_job("test", {})
+
+    assert job.id == "test"
+    assert job.title == "live_module_call.test"
+    assert job.name is None
+    assert job.image == "ubuntu"
+    assert job.preset == "test-preset"
+    assert job.http_port is None
+    assert not job.http_auth
+    assert job.entrypoint is None
+    assert job.cmd == "bash -euo pipefail -c 'echo A val 1 B live_module_call C'"
+    assert job.workdir == pathlib.PurePosixPath("/some/dir")
+    assert job.volumes == ["storage:test:/volume"]
+    assert job.tags == {
+        "project:unit",
+        "flow:live-module-call",
+        "job:test",
+        "test-tag",
+    }
+    assert job.env == {"TEST": "test_value"}
+    assert job.life_span == timedelta(days=2).total_seconds()
+    assert job.schedule_timeout == timedelta(minutes=60).total_seconds()
+    assert job.port_forward == []
+    assert not job.detach
+    assert not job.browse
+
+
+async def test_job_with_live_call_to_remote_module_invalid(
+    live_config_loader: ConfigLoader,
+) -> None:
+    flow = await RunningLiveFlow.create(live_config_loader, "live-module-remote-call")
+    with pytest.raises(
+        EvalError,
+        match=r"Module call to non local action 'gh:username/repo@tag' is forbidden",
+    ):
+        await flow.get_job("test", {})
+
+
 async def test_job_with_params(live_config_loader: ConfigLoader) -> None:
     flow = await RunningLiveFlow.create(live_config_loader, "live-params")
     job = await flow.get_job("test", {"arg1": "value"})
@@ -712,7 +752,7 @@ async def test_job_with_params(live_config_loader: ConfigLoader) -> None:
     assert job.http_port is None
     assert not job.http_auth
     assert job.entrypoint is None
-    assert job.cmd == "bash -euo pipefail -c 'echo value val2'"
+    assert job.cmd == "bash -euo pipefail -c 'echo value val2 live_params'"
     assert job.workdir is None
     assert job.volumes == []
     assert job.tags == {
@@ -878,3 +918,23 @@ def test_sanitize_name() -> None:
     assert sanitize_name("my//project") == "my/project"
     assert sanitize_name("/my/project/") == "my/project"
     assert sanitize_name("") == "_"
+
+
+async def test_batch_module_call_to_remote_invalid(
+    assets: pathlib.Path, client: Client
+) -> None:
+    ws = assets / "batch_module"
+    config_dir = ConfigDir(
+        workspace=ws,
+        config_dir=ws,
+    )
+    cl = BatchLocalCL(config_dir, client)
+    try:
+        with pytest.raises(
+            EvalError,
+            match=r"Module call to non local action 'gh:username/repo@tag' "
+            r"is forbidden",
+        ):
+            await RunningBatchFlow.create(cl, "batch-module-remote-call", "bake-id")
+    finally:
+        await cl.close()
